@@ -363,7 +363,7 @@ class TestConnectionPool(HTTPDummyServerTestCase):
         with HTTPConnectionPool(self.host, port) as pool:
             with pytest.raises(MaxRetryError) as e:
                 pool.request("GET", "/", retries=Retry(connect=3))
-            assert type(e.value.reason) == NewConnectionError
+            assert type(e.value.reason) is NewConnectionError
 
     def test_timeout_success(self) -> None:
         timeout = Timeout(connect=3, read=5, total=None)
@@ -480,11 +480,22 @@ class TestConnectionPool(HTTPDummyServerTestCase):
             assert r.status == 200
             assert r.data == b"Dummy server!"
 
+    def test_303_redirect_makes_request_lose_body(self) -> None:
+        with HTTPConnectionPool(self.host, self.port) as pool:
+            response = pool.request(
+                "POST",
+                "/redirect",
+                fields={"target": "/headers_and_params", "status": "303 See Other"},
+            )
+        data = response.json()
+        assert data["params"] == {}
+        assert "Content-Type" not in HTTPHeaderDict(data["headers"])
+
     def test_bad_connect(self) -> None:
         with HTTPConnectionPool("badhost.invalid", self.port) as pool:
             with pytest.raises(MaxRetryError) as e:
                 pool.request("GET", "/", retries=5)
-            assert type(e.value.reason) == NameResolutionError
+            assert type(e.value.reason) is NameResolutionError
 
     def test_keepalive(self) -> None:
         with HTTPConnectionPool(self.host, self.port, block=True, maxsize=1) as pool:
@@ -1052,7 +1063,7 @@ class TestConnectionPool(HTTPDummyServerTestCase):
                 conn.request("GET", "/headers", chunked=chunked)
 
             assert pool.headers == {"key": "val"}
-            assert isinstance(pool.headers, header_type)
+            assert type(pool.headers) is header_type
 
         with HTTPConnectionPool(self.host, self.port) as pool:
             if pool_request:
