@@ -15,16 +15,10 @@ import sys
 import tempfile
 import time
 import typing
+import zlib
 from collections import OrderedDict
 from pathlib import Path
-from test import (
-    LONG_TIMEOUT,
-    SHORT_TIMEOUT,
-    notSecureTransport,
-    notWindows,
-    requires_ssl_context_keyfile_password,
-    resolvesLocalhostFQDN,
-)
+from test import LONG_TIMEOUT, SHORT_TIMEOUT, notWindows, resolvesLocalhostFQDN
 from threading import Event
 from unittest import mock
 
@@ -328,11 +322,9 @@ class TestClientCerts(SocketDummyServerTestCase):
                 done_receiving.set()
             done_receiving.set()
 
-    @requires_ssl_context_keyfile_password()
     def test_client_cert_with_string_password(self) -> None:
         self.run_client_cert_with_password_test("letmein")
 
-    @requires_ssl_context_keyfile_password()
     def test_client_cert_with_bytes_password(self) -> None:
         self.run_client_cert_with_password_test(b"letmein")
 
@@ -384,7 +376,6 @@ class TestClientCerts(SocketDummyServerTestCase):
 
             assert len(client_certs) == 1
 
-    @requires_ssl_context_keyfile_password()
     def test_load_keyfile_with_invalid_password(self) -> None:
         assert ssl_.SSLContext is not None
         context = ssl_.SSLContext(ssl_.PROTOCOL_SSLv23)
@@ -395,9 +386,6 @@ class TestClientCerts(SocketDummyServerTestCase):
                 password=b"letmei",
             )
 
-    # For SecureTransport, the validation that would raise an error in
-    # this case is deferred.
-    @notSecureTransport()
     def test_load_invalid_cert_file(self) -> None:
         assert ssl_.SSLContext is not None
         context = ssl_.SSLContext(ssl_.PROTOCOL_SSLv23)
@@ -992,9 +980,7 @@ class TestSocketClosing(SocketDummyServerTestCase):
         ) as f:
             ssl_sock.close()
             f.close()
-            # SecureTransport is supposed to raise OSError but raises
-            # ssl.SSLError when closed because ssl_sock.context is None
-            with pytest.raises((OSError, ssl.SSLError)):
+            with pytest.raises(OSError):
                 ssl_sock.sendall(b"hello")
             assert ssl_sock.fileno() == -1
 
@@ -1274,7 +1260,7 @@ class TestProxyManager(SocketDummyServerTestCase):
 
             errored.set()  # Avoid a ConnectionAbortedError on Windows.
 
-            assert type(e.value.reason) == ProxyError
+            assert type(e.value.reason) is ProxyError
             assert "Your proxy appears to only use HTTP and not HTTPS" in str(
                 e.value.reason
             )
@@ -1285,16 +1271,13 @@ class TestSSL(SocketDummyServerTestCase):
         def socket_handler(listener: socket.socket) -> None:
             sock = listener.accept()[0]
             sock2 = sock.dup()
-            try:
-                ssl_sock = original_ssl_wrap_socket(
-                    sock,
-                    server_side=True,
-                    keyfile=DEFAULT_CERTS["keyfile"],
-                    certfile=DEFAULT_CERTS["certfile"],
-                    ca_certs=DEFAULT_CA,
-                )
-            except ssl.SSLError:
-                return
+            ssl_sock = original_ssl_wrap_socket(
+                sock,
+                server_side=True,
+                keyfile=DEFAULT_CERTS["keyfile"],
+                certfile=DEFAULT_CERTS["certfile"],
+                ca_certs=DEFAULT_CA,
+            )
 
             buf = b""
             while not buf.endswith(b"\r\n\r\n"):
@@ -1312,12 +1295,12 @@ class TestSSL(SocketDummyServerTestCase):
             ssl_sock.close()
 
         self._start_server(socket_handler)
-        with HTTPSConnectionPool(self.host, self.port) as pool:
-            with pytest.raises(MaxRetryError) as cm:
-                pool.request("GET", "/", retries=0)
-            assert isinstance(cm.value.reason, SSLError)
+        with HTTPSConnectionPool(self.host, self.port, ca_certs=DEFAULT_CA) as pool:
+            with pytest.raises(
+                SSLError, match=r"(wrong version number|record overflow)"
+            ):
+                pool.request("GET", "/", retries=False)
 
-    @notSecureTransport()
     def test_ssl_read_timeout(self) -> None:
         timed_out = Event()
 
@@ -1406,7 +1389,7 @@ class TestSSL(SocketDummyServerTestCase):
 
         with pytest.raises(MaxRetryError) as cm:
             request()
-        assert isinstance(cm.value.reason, SSLError)
+        assert type(cm.value.reason) is SSLError
         # Should not hang, see https://github.com/urllib3/urllib3/issues/529
         with pytest.raises(MaxRetryError):
             request()
@@ -1601,9 +1584,6 @@ class TestSSL(SocketDummyServerTestCase):
                 pool.request("GET", "/", retries=False, timeout=LONG_TIMEOUT)
         assert server_closed.wait(LONG_TIMEOUT), "The socket was not terminated"
 
-    # SecureTransport can read only small pieces of data at the moment.
-    # https://github.com/urllib3/urllib3/pull/2674
-    @notSecureTransport()
     @pytest.mark.skipif(
         os.environ.get("CI") == "true" and sys.implementation.name == "pypy",
         reason="too slow to run in CI",
@@ -1903,7 +1883,7 @@ class TestBrokenHeaders(SocketDummyServerTestCase):
             for record in logs:
                 if (
                     "Failed to parse headers" in record.msg
-                    and isinstance(record.args, tuple)
+                    and type(record.args) is tuple
                     and _url_from_pool(pool, "/") == record.args[0]
                 ):
                     if (
@@ -2003,6 +1983,54 @@ class TestStream(SocketDummyServerTestCase):
 
             done_event.set()
 
+    def test_large_compressed_stream(self) -> None:
+        done_event = Event()
+        expected_total_length = 296085
+
+        def socket_handler(listener: socket.socket) -> None:
+            compress = zlib.compressobj(6, zlib.DEFLATED, 16 + zlib.MAX_WBITS)
+            data = compress.compress(b"x" * expected_total_length)
+            data += compress.flush()
+
+            sock = listener.accept()[0]
+
+            buf = b""
+            while not buf.endswith(b"\r\n\r\n"):
+                buf += sock.recv(65536)
+
+            sock.sendall(
+                b"HTTP/1.1 200 OK\r\n"
+                b"Content-Length: %d\r\n"
+                b"Content-Encoding: gzip\r\n"
+                b"\r\n" % (len(data),) + data
+            )
+
+            done_event.wait(5)
+            sock.close()
+
+        self._start_server(socket_handler)
+
+        with HTTPConnectionPool(self.host, self.port, retries=False) as pool:
+            r = pool.request("GET", "/", timeout=LONG_TIMEOUT, preload_content=False)
+
+            # Chunks must all be equal or less than 10240
+            # and only the last chunk is allowed to be smaller
+            # than 10240.
+            total_length = 0
+            chunks_smaller_than_10240 = 0
+            for chunk in r.stream(10240, decode_content=True):
+                assert 0 < len(chunk) <= 10240
+                if len(chunk) < 10240:
+                    chunks_smaller_than_10240 += 1
+                else:
+                    assert chunks_smaller_than_10240 == 0
+                total_length += len(chunk)
+
+            assert chunks_smaller_than_10240 == 1
+            assert expected_total_length == total_length
+
+            done_event.set()
+
 
 class TestBadContentLength(SocketDummyServerTestCase):
     def test_enforce_content_length_get(self) -> None:
